% Warming Stripes
% Nina Kirchner, April to June 2019, Stockholm University,
% nina.kirchner@natgeo.su.se
%
% Reads a data file, plots its Warming Stripe and saves it as a png file.
%
% After an idea of Ed Hawkins, https://www.climate-lab-book.ac.uk/2018/warming-stripes/
% In Cooperation with Anders Moberg and Rezwan Mohammad, Stockholm University

% Revised by Anders Moberg, June 2019
% anders.moberg@natgeo.su.se

clear all, close all

% Choose data series to plot by uncommenting appropriate line below.
% Any other similar data file may also be used, provided that
% it is a csv file having two columns, Year & Data, separated by a comma.
%

fid = fopen('Stockholm_MeanAnnualTemp_1756-2018.csv');
%fid = fopen('Uppsala_MeanAnnualTemp_1722-2018.csv');
%fid = fopen('Sweden_MeanAnnualTemp_1860-2018.csv');
%fid = fopen('Svalbard_MeanAnnualTemp_1898-2018.csv');



Data = textscan(fid, '%f  %f', 'delimiter', ',');
fclose(fid);

Years = Data{1};
Temp = Data{2};

% Below, the last value in the Years and Temp vectors, respectively,
% is copied and appended as an extra value at the end. 
% This is done because the function pcolor, which is used to plot
% the Warming stripe, needs an extra copy of the last value.
% See https://se.mathworks.com/help/matlab/ref/pcolor.html
%
Years=[Years;Years(end)]; 
Temp=[Temp;Temp(end)];

ll=min(Temp);
ul=max(Temp);

Temp_plotting = [Temp Temp];
Temp_plotting= Temp_plotting.';

% Define the colours to plot
cmap_ws =  [0 0 0.5                  % Navy
             0 0 0.8008              % Medium Blue  
             0.1172 0.5625 1.0       % DodgerBlue
             0.5273 0.8047 0.9792    % LightSkyBlue
             1.0 0.9792 0.9792       % Snow
             1.0 0.8516 0.7227       % Peach Puff
             1.0000  0.4961 0.3125   % Coral
             0.8594 0.0781 0.2344    % crimson
             0.5430 0 0];            % dark red

%  Plot the Warming stripe using pcolor                  
figure
pcolor(Temp_plotting)
shading flat
colormap(cmap_ws);

caxis([ll ul]) % 
set(gca, 'YTickLabel', [])
set(gca, 'YTick' , [])
set(gca, 'XTickLabel', [])
set(gca, 'XTick', [])
set(gca, 'TickLength', [0 0])
set(gca,'position',[0.1300    0.1100    0.7750    0.8150*.53])

% the below colorbar command is optional, uncomment if colorbar shall be displayed
%colorbar

% uncomment the line below if a png file should not be created
set(gca,'box','off','xcolor',.999*ones(1,3)),print -dpng WarmingStripe